CRSD Version 1.0 elements (sarpy.io.received.crsd1_elements)
=================================================================

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    crsd
    collection_id
    global
    data
    channel
    pvp
    reference_geometry
    antenna
    error_parameters
